#------------------------------------------------------------------------------
# pix module for manipulating Picture objects (based on graphics.py)
# version 11/10/2020
#
# img = Picture()               create new blank Picture of size 300 x 300
# img = Picture(width, height)  create new blank Picture of size width x height
# img = Picture(filename)       create new Picture from a GIF or PPM file
# 
# img.getPixel(x, y)            return the pixel at location (x, y) as [R,G,B]
# img.setPixel(x, y, [R,G,B])   set the pixel at location (x, y) to [R,G,B]
# img.save(filename)            save the Picture as a GIF or PPM file
# img2 = img.clone()            create an identical copy of a Picture
# img.getWidth()                return number of horizontal pixels
# img.getHeight()               return number of vertical pixels
# img.update()                  immediately update the graphics window
#
#------------------------------------------------------------------------------
from graphics import *

class Picture(GraphWin):

    FILETYPES = ['.gif', '.ppm']

    def __init__(self, *args):
        assert len(args) <= 2, "wrong number of arguments"
        if len(args) == 1:
            filename = args[0]
            assert filename[-4:].lower() in Picture.FILETYPES, "file type must be GIF or PPM"
            img = Image(Point(0,0), filename)
            w, h = img.getWidth(), img.getHeight()
            self.img = Image(Point(w//2,h//2), filename)
            GraphWin.__init__(self, filename, w, h)
        else:
            if len(args) == 0:
                w, h = 300, 300
            else:
                w, h = args
            self.img = Image(Point(w//2, h//2), w, h)
            GraphWin.__init__(self, "", w, h)
        self.setBackground("black")
        self.img.draw(self)

    def getPixel(self, x, y):
        return self.img.getPixel(x, y)

    def setPixel(self, x, y, newPixel):
        r, g, b = newPixel
        try:
            self.img.setPixel(x, y, color_rgb(r, g, b))
        except TypeError:
            raise Exception("RGB values must be of type int")
        
    def save(self, filename):
        if filename[-4:].lower() not in Picture.FILETYPES:
            print("Sorry, file type must be GIF or PPM")
        else:
            self.img.save(filename)
            print("Picture saved as", filename)

    def clone(self):
        w, h = self.getWidth(), self.getHeight()
        new = Picture(w, h)
        for x in range(w):
            for y in range(h):
                new.setPixel(x, y, self.getPixel(x, y))
        new.update()
        return new
